%% SwanOne model 
% SWAN model to simulate 1D wave development

clc
clear
close all
fclose('all');

% removal of s files and directory 
if exist('norm_end','file')==2
    delete('norm_end')
end
sFolder = strcat(pwd,'\Working Directory');    
if exist(sFolder,'dir')==7
  try
    rmpath(sFolder);
    rmdir(sFolder,'s');
  end
end

% creating structure for all the information
global handles
handles=struct;
handles.swan1d.fig1=figure('Menubar','none','Name','SwanOne','NumberTitle','off','Tag','swan1d','units','normalized','outerposition',[0 0 1 1],'color',[0.8 0.8 0.8]);
% to fill screen use: figure('units','normalized','outerposition',[0 0 1 1])

% 'Welcome...' text
%handles.swan1d.modeltext1=annotation(handles.swan1d.fig1,'textbox','EdgeColor','none','FontSize',20,'String','Welcome to','Position',[0.2 -0.22 0.4 0.5]);
%handles.swan1d.modeltext2=annotation(handles.swan1d.fig1,'textbox','EdgeColor','none','FontSize',40,'String','SwanOne','Position',[0.32 -0.47 1 0.7]);
%handles.swan1d.modeltext3=annotation(handles.swan1d.fig1,'textbox','EdgeColor','none','FontSize',7,'String','Copyright 2015 TUDelft - Hydraulic Engineering','Position',[0.60 -0.65 1 0.7]);

% logo
im=imread('swanone_logo.png');
clf
axes('position',[0.45,0.05,0.49,0.58])
imshow(im)
text(max(xlim),max(ylim),{'Version 1.3 (April 2018)', 'Based on SWAN v41.20'},...
    'HorizontalAlignment','right','FontSize', 12);

%% 'File' button
handles.swan1d.menu.file.m=uimenu(handles.swan1d.fig1,'label','File');

% 'New...' button to start new project
handles.swan1d.menu.file.new=uimenu(handles.swan1d.menu.file.m,'label','New','Callback',@new_clbk_str);

% 'Open...' button to open existing project
%handles.swan1d.menu.file.open=uimenu(handles.swan1d.menu.file.m,'label','Open','Enable','Off','Callback',@open_clbk_str);

% 'Save' button to save project
%handles.swan1d.menu.file.save=uimenu(handles.swan1d.menu.file.m,'label','Save','Separator','on','Enable','Off','Callback',@save_clbk_str);

% 'Save as' button to save project
%handles.swan1d.menu.file.saveas=uimenu(handles.swan1d.menu.file.m,'label','Save As','Enable','Off','Callback',@save_as_clbk_str);

% 'Exit' button to leave model
handles.swan1d.menu.file.exit=uimenu(handles.swan1d.menu.file.m,'label','Exit','Callback','close all','Separator','on');

%% 'Input' button
handles.swan1d.menu.input.m=uimenu(handles.swan1d.fig1,'label','Input','Enable','Off');

% 'Bottom Profile' button to define depths and distances
handles.swan1d.menu.input.bottomprofile=uimenu(handles.swan1d.menu.input.m,'label','Bottom Profile','Callback',@btm_profile_clbk);

% 'Boundary Conditions' button to define boundaries parameters
handles.swan1d.menu.input.boundaryconditions=uimenu(handles.swan1d.menu.input.m,'label','Boundary Conditions','Callback',@bound_cnd_clbk);

% 'Define Currents' button to define the flow velocities
handles.swan1d.menu.input.definecurrents=uimenu(handles.swan1d.menu.input.m,'label','Define Currents','Callback',@def_current_clbk,'Enable','Off');

% 'Output Locations' button to define locations
handles.swan1d.menu.input.outputlocations=uimenu(handles.swan1d.menu.input.m,'label','Output Locations','Callback',@output_location_clbk);

% 'Computation' button to activate the calculation
handles.swan1d.menu.computation.m=uimenu(handles.swan1d.fig1,'label','Computation','Enable','Off');
handles.swan1d.menu.computation.start=uimenu(handles.swan1d.menu.computation.m,'label','Start','Callback',@comp_start_clbk);

%% 'Output' button
handles.swan1d.menu.output.m=uimenu(handles.swan1d.fig1,'label','Output','Enable','Off');

% 'Rayplot' button to show various rayplots
handles.swan1d.menu.output.raysplot=uimenu(handles.swan1d.menu.output.m,'label','Rays Plot','Callback',@output_raysplot_clbk);

% 'Spectrumplot' button to show 1D spectrum
handles.swan1d.menu.output.spectrumplot=uimenu(handles.swan1d.menu.output.m,'label','Spectrum Plot','Callback',@output_spectrumplot_clbk);

% 'Tables' button to show various tables
handles.swan1d.menu.output.tables=uimenu(handles.swan1d.menu.output.m,'label','Tables','Separator','on','Callback',@output_table_clbk);

%% 'Help' button
% handles.swan1d.menu.help=uimenu(handles.swan1d.fig1,'label','Help','Callback',@help_clbk);

% Subscribe values to structure and set to Userdata and GUIdata property
handles.swan1d.folder=cd;
set(handles.swan1d.fig1,'UserData',handles);
guidata(handles.swan1d.fig1,handles);
