function [freq,efr,xpos,ypos,iok] = read_swan_sp1(specname,iloc)
%
% function [freq,efr,xpos,ypos,iok] = read_swan_sp1(specname,iloc)
%
% specname: name of spectrum file
% iloc    : sequence number in file
%         : if iloc ==0, then all spectra are read and stored in the array efr
%
% retrieve 1-d spectra in a SWAN 1-d spectrum file
% version 40.00 and higher
%
%  Gerbrant van Vledder
%  12/03/2003   Help added, iloc=0 option debugged
%  22/01/2004   Automatic detection of strings AFREQ/RFREQ 
%
freq = [];
efr = [];
xpos = [];
ypos = [];
iok = 0;
fid = fopen(specname);
if fid > 0
  iok = 1;
  [found] = findtext(fid, 'LOCATIONS');
  xline = fgets(fid);
  nloc = sscanf(xline,'%e',1);
  xydata = fscanf(fid,'%e\n',[2,nloc]);
  xloc = xydata(1,:);
  yloc = xydata(2,:);
  %
  if iloc==0
    xpos = xloc;
    ypos = yloc;
  else
    xpos = xloc(iloc);
    ypos = yloc(iloc);
  end
%
  %  check number of locations in data file with requested output location
  %
  if iloc > nloc
     iok = 0;
     disp('Warning: requested output location does not exist')
     return
  end
  %
  % search spectral information
  %
  ztext = fgetl(fid);
  
%  found = findtext(fid,'AFREQ');
  xline = fgets(fid);
  nfreq = sscanf(xline,'%e',1);
  freq = fscanf(fid,'%e',nfreq);
  %
  found = findtext(fid,'QUANT');
  xline = fgets(fid);
  nquant = sscanf(xline,'%e',1);
  for iquant=1:nquant
     xline1 = fgets(fid);
     xline2 = fgets(fid);
     xline3 = fgets(fid);
  end
  %
  for jloc=1:nloc
    yline = fgets(fid);
    if isspace(yline) ==1
       yline = fgets(fid);
    end
%    yline;
%    yline = fgets(fid)
    if strcmp(strtok(yline),'NODATA') | strcmp(strtok(yline),'ZERO')
       data = zeros(nquant,nfreq);
     else
%       [loc,lnum] = strtok(yline);
%       kloc = sscanf(lnum,'%e',1);
%
%  rescan first line that has not been reognized as a text field
%
%      [data0] = sscanf(yline,'%e',[nquant,1]);
      [data] = fscanf(fid,'%e',[nquant,nfreq]);
%
% concatenate data
%
%      data = [data0 data];
    end
    data = data';
    if iloc == jloc
      efr = data(:,1);
      return
    elseif iloc==0
      if jloc ==1
         efr = data(:,1);
      else
         efr = [efr data(:,1)];
      end
    end
  end
  iok = 1;
  fclose(fid);
  %
else
   disp(['File ' specname ' does not exist'])
   iok = 0;
end